==> hinemos_src-2.4.3.tar.gz: Hinemos_src-2.4.3/MonitorRunEJB/src/com/clustercontrol/monitor/run/factory/SelectMonitorStringValueType.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.monitor.run.factory;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;
import java.util.Locale;

import javax.ejb.CreateException;
import javax.ejb.FinderException;
import javax.naming.NamingException;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.eclipse.swt.SWT;
import org.quartz.SchedulerException;

import com.clustercontrol.bean.TableColumnInfo;
import com.clustercontrol.bean.ValidConstant;
import com.clustercontrol.monitor.run.bean.MonitorStringValueInfo;
import com.clustercontrol.monitor.run.bean.StringValueListTabelDefine;
import com.clustercontrol.monitor.run.ejb.entity.MonitorStringValueInfoLocal;
import com.clustercontrol.util.Messages;

/**
 * 文字列監視の判定情報を検索する抽象クラス<BR>
 * <p>
 * 文字列監視を行う各監視管理クラスで継承してください。
 *
 * @version 2.1.0
 * @since 2.1.0
 */
abstract public class SelectMonitorStringValueType extends SelectMonitor{
	
	/** ログ出力のインスタンス。 */
	protected static Log m_log = LogFactory.getLog( SelectMonitorStringValueType.class );

	/**
	 * 監視情報より文字列監視の判定情報を返します。
	 * <p>
	 * <ol>
	 * <li>監視情報より、文字列監視判定情報を取得します。</li>
	 * <li>１判定情報をビーン（{@link com.clustercontrol.monitor.run.bean.MonitorStringValueInfo}）にセットします。</li>
	 * <li>このビーンを、判定情報を保持するリスト（{@link ArrayList}）にセットし返します。<BR>
	 * </ol>
	 * 
	 * @see com.clustercontrol.monitor.run.ejb.entity.MonitorInfoBean
	 * @see com.clustercontrol.monitor.run.ejb.entity.MonitorStringValueInfoBean
	 * @see com.clustercontrol.monitor.run.bean.MonitorStringValueInfo
	 */
	@Override
	public ArrayList getJudgementInfo() throws FinderException, NamingException {
		
		// 文字列監視判定情報を取得
		Collection ct = m_monitor.getMonitorStringValueInfo();
        Iterator itr = ct.iterator();
		
		ArrayList<MonitorStringValueInfo> valueList = new ArrayList<MonitorStringValueInfo>();
		
		MonitorStringValueInfoLocal local = null;
        while(itr.hasNext()){
            local = (MonitorStringValueInfoLocal)itr.next();
            MonitorStringValueInfo value = new MonitorStringValueInfo(
            		local.getMonitorTypeId(),
            		local.getMonitorId(),
            		local.getOrderNo().intValue(),
            		local.getDescription(),
            		local.getProcessType().intValue(),
            		local.getPattern(),
            		local.getPriority().intValue(),
            		local.getMessageId(),
            		local.getMessage(),
            		local.getNotifyId(),
            		local.getJobRun().intValue(),
            		local.getJobId(),
            		local.getJobInhibitionFlg().intValue(),
            		local.getJobFailurePriority().intValue(),
            		ValidConstant.typeToBoolean(local.getValidFlg().intValue()));
            valueList.add(value);
        }
		return valueList;
	}
	
	/**
	 * 文字列監視判定一覧のテーブル定義情報を返します。
	 * 
	 * @param locale ロケール情報
	 * @return テーブル定義情報（{@link com.clustercontrol.bean.TableColumnInfo}のリスト）
	 * @throws CreateException
	 * @throws FinderException
	 * @throws SchedulerException
	 * @throws NamingException
	 * 
	 * @see com.clustercontrol.bean.TableColumnInfo#TableColumnInfo(java.lang.String, int, int, int)
	 * @see com.clustercontrol.monitor.run.bean.StringValueListTabelDefine
	 */
	@SuppressWarnings("unchecked")
	public ArrayList getStringValueListTableDefine(Locale locale) {

		/** テーブル情報定義配列 */
		ArrayList tableDefine = new ArrayList();

		tableDefine.add(StringValueListTabelDefine.ORDER_NO, 
				new TableColumnInfo(Messages.getString("order", locale), TableColumnInfo.NONE, 40, SWT.RIGHT));
		tableDefine.add(StringValueListTabelDefine.PROCESS_TYPE, 
				new TableColumnInfo(Messages.getString("process", locale), TableColumnInfo.PROCESS, 50, SWT.LEFT));
		tableDefine.add(StringValueListTabelDefine.DESCRIPTION, 
				new TableColumnInfo(Messages.getString("description", locale), TableColumnInfo.NONE, 180, SWT.LEFT));
		tableDefine.add(StringValueListTabelDefine.NOTIFY_ID, 
				new TableColumnInfo(Messages.getString("notify.id", locale), TableColumnInfo.NONE, 80, SWT.LEFT));
		tableDefine.add(StringValueListTabelDefine.MESSAGE_ID, 
				new TableColumnInfo(Messages.getString("message.id", locale), TableColumnInfo.NONE, 90, SWT.LEFT));

		return tableDefine;
	}
}

==> hinemos_src-3.0.5.tar.gz: Hinemos_src-3.0.5/MonitorRunEJB/src/com/clustercontrol/monitor/run/factory/SelectMonitorStringValueType.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.monitor.run.factory;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;
import java.util.Locale;

import javax.ejb.CreateException;
import javax.ejb.FinderException;
import javax.naming.NamingException;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.eclipse.swt.SWT;
import org.quartz.SchedulerException;

import com.clustercontrol.bean.TableColumnInfo;
import com.clustercontrol.bean.ValidConstant;
import com.clustercontrol.monitor.run.bean.MonitorStringValueInfo;
import com.clustercontrol.monitor.run.bean.StringValueListTabelDefine;
import com.clustercontrol.monitor.run.ejb.entity.MonitorStringValueInfoLocal;
import com.clustercontrol.notify.bean.NotifyRelationInfo;
import com.clustercontrol.notify.ejb.session.NotifyControllerLocal;
import com.clustercontrol.notify.ejb.session.NotifyControllerUtil;
import com.clustercontrol.util.Messages;

/**
 * 文字列監視の判定情報を検索する抽象クラス<BR>
 * <p>
 * 文字列監視を行う各監視管理クラスで継承してください。
 *
 * @version 3.0.0
 * @since 2.1.0
 */
abstract public class SelectMonitorStringValueType extends SelectMonitor{
	
	/** ログ出力のインスタンス。 */
	protected static Log m_log = LogFactory.getLog( SelectMonitorStringValueType.class );

	/**
	 * 監視情報より文字列監視の判定情報を返します。
	 * <p>
	 * <ol>
	 * <li>監視情報より、文字列監視判定情報を取得します。</li>
	 * <li>１判定情報をビーン（{@link com.clustercontrol.monitor.run.bean.MonitorStringValueInfo}）にセットします。</li>
	 * <li>このビーンを、判定情報を保持するリスト（{@link ArrayList}）にセットし返します。<BR>
	 * </ol>
	 * 
	 * @see com.clustercontrol.monitor.run.ejb.entity.MonitorInfoBean
	 * @see com.clustercontrol.monitor.run.ejb.entity.MonitorStringValueInfoBean
	 * @see com.clustercontrol.monitor.run.bean.MonitorStringValueInfo
	 */
	@Override
	public ArrayList getJudgementInfo() throws FinderException, NamingException {
		
		// 文字列監視判定情報を取得
		Collection ct = m_monitor.getMonitorStringValueInfo();
        Iterator itr = ct.iterator();
		
		ArrayList<MonitorStringValueInfo> valueList = new ArrayList<MonitorStringValueInfo>();
		
		try {
			
			//通知用のセッションビーンを初期化
			NotifyControllerLocal	nc = NotifyControllerUtil.getLocalHome().create();
		
			
			Collection<NotifyRelationInfo> notifyId;
		
		MonitorStringValueInfoLocal local = null;
        
		while(itr.hasNext()){
            local = (MonitorStringValueInfoLocal)itr.next();
            String notifyGroupId = local.getNotifyGroupId();
           notifyId = nc.getNotifyRelation(local.getNotifyGroupId());
			
            
            MonitorStringValueInfo value = new MonitorStringValueInfo(
            		local.getMonitorTypeId(),
            		local.getMonitorId(),
            		local.getOrderNo().intValue(),
            		local.getDescription(),
            		local.getProcessType().intValue(),
            		local.getPattern(),
            		local.getPriority().intValue(),
            		local.getMessageId(),
            		local.getMessage(),
            		local.getNotifyGroupId(),
            		notifyId,
            		ValidConstant.typeToBoolean(local.getValidFlg().intValue())
            		);
            
            /**
             * MonitorStringValueInfo value = new MonitorStringValueInfo(
            		local.getMonitorTypeId(),
            		local.getMonitorId(),
            		local.getOrderNo().intValue(),
            		local.getDescription(),
            		local.getProcessType().intValue(),
            		local.getPattern(),
            		local.getPriority().intValue(),
            		local.getMessageId(),
            		local.getMessage(),
            		local.getNotifyGroupId(),
            		notifyId,
            		ValidConstant.typeToBoolean(local.getValidFlg().intValue())
            		);
             */
            
            valueList.add(value);
        }
		return valueList;
		
		} catch (CreateException e) {
		
			e.printStackTrace();
		}
		
		return null;
	}
	
	/**
	 * 文字列監視判定一覧のテーブル定義情報を返します。
	 * 
	 * @param locale ロケール情報
	 * @return テーブル定義情報（{@link com.clustercontrol.bean.TableColumnInfo}のリスト）
	 * @throws CreateException
	 * @throws FinderException
	 * @throws SchedulerException
	 * @throws NamingException
	 * 
	 * @see com.clustercontrol.bean.TableColumnInfo#TableColumnInfo(java.lang.String, int, int, int)
	 * @see com.clustercontrol.monitor.run.bean.StringValueListTabelDefine
	 */
	@SuppressWarnings("unchecked")
	public ArrayList getStringValueListTableDefine(Locale locale) {

		/** テーブル情報定義配列 */
		ArrayList tableDefine = new ArrayList();

		tableDefine.add(StringValueListTabelDefine.ORDER_NO, 
				new TableColumnInfo(Messages.getString("order", locale), TableColumnInfo.NONE, 40, SWT.RIGHT));
		tableDefine.add(StringValueListTabelDefine.PROCESS_TYPE, 
				new TableColumnInfo(Messages.getString("process", locale), TableColumnInfo.PROCESS, 50, SWT.LEFT));
		tableDefine.add(StringValueListTabelDefine.DESCRIPTION, 
				new TableColumnInfo(Messages.getString("description", locale), TableColumnInfo.NONE, 180, SWT.LEFT));
		tableDefine.add(StringValueListTabelDefine.VALID_FLG, 
				new TableColumnInfo(Messages.getString("valid", locale) + "/" + Messages.getString("invalid", locale), TableColumnInfo.VALID, 80, SWT.LEFT));;
		tableDefine.add(StringValueListTabelDefine.MESSAGE_ID, 
				new TableColumnInfo(Messages.getString("message.id", locale), TableColumnInfo.NONE, 90, SWT.LEFT));

		return tableDefine;
	}
}
